@@ -233,18 +233,18 @@ def create_scan_yml(scan_definition: str | Path) -> ScanYml:
     return scan_yml
 
 
-def create_warehouse_yml() -> WarehouseYml:
+def create_warehouse_yml(warehouse_name: str = "sodaspark") -> WarehouseYml:
     """Create Spark a ware house yml."""
     warehouse_yml = WarehouseYml(
-        name="sodaspark",
+        name=warehouse_name,
         dialect=_SparkDialect(),
     )
     return warehouse_yml
 
 
-def create_warehouse() -> Warehouse:
+def create_warehouse(warehouse_name: str = "spdaspark") -> Warehouse:
     """Create a ware house."""
-    warehouse_yml = create_warehouse_yml()
+    warehouse_yml = create_warehouse_yml(warehouse_name)
     warehouse = Warehouse(warehouse_yml)
     return warehouse
 
@@ -252,7 +252,9 @@ def create_warehouse() -> Warehouse:
 def create_scan(
     scan_yml: ScanYml,
     variables: dict | None = None,
+    warehouse_name: str = "sodaspark",
     soda_server_client: SodaServerClient | None = None,
+    time: str | None = None,
 ) -> Scan:
     """
     Create a scan object.
@@ -264,19 +266,25 @@ def create_scan(
     variables: variables to be substituted in scan yml
     soda_server_client : Optional[SodaServerClient] (default : None)
         A soda server client.
+    time: Optional[str] (default: None)
+        Timestamp date in ISO8601 format. If None, use datatime.now() in ISO8601 format.
 
     Returns
     -------
     out : Scan
         The scan.
     """
-    warehouse = create_warehouse()
+
+    time = time or dt.datetime.now(tz=dt.timezone.utc).isoformat(
+        timespec="seconds"
+    )
+    warehouse = create_warehouse(warehouse_name)
     scan = Scan(
         warehouse=warehouse,
         scan_yml=scan_yml,
         soda_server_client=soda_server_client,
         variables=variables,
-        time=dt.datetime.now(tz=dt.timezone.utc).isoformat(timespec="seconds"),
+        time=time,
     )
     return scan
 
@@ -418,8 +426,10 @@ def execute(
     df: DataFrame,
     *,
     variables: dict | None = None,
+    warehouse_name: str = "sodaspark",
     soda_server_client: SodaServerClient | None = None,
     as_frames: bool | None = False,
+    time: str | None = None,
 ) -> ScanResult:
     """
     Execute a scan on a data frame.
@@ -436,6 +446,8 @@ def execute(
         A soda server client.
     as_frames : bool (default : False)
         Flag to return results in Dataframe
+    time: str (default : None)
+        Timestamp date in ISO8601 format at the start of a scan
 
     Returns
     -------
@@ -446,7 +458,11 @@ def execute(
     df.createOrReplaceTempView(scan_yml.table_name)
 
     scan = create_scan(
-        scan_yml, variables=variables, soda_server_client=soda_server_client
+        scan_yml,
+        variables=variables,
+        soda_server_client=soda_server_client,
+        time=time,
+        warehouse_name=warehouse_name,
     )
     scan.execute()
 
